/* -----------------------------------------------------------------------------
 * Copyright (c) 2015 ARM Ltd.
 *
 * This software is provided 'as-is', without any express or implied warranty. 
 * In no event will the authors be held liable for any damages arising from 
 * the use of this software. Permission is granted to anyone to use this 
 * software for any purpose, including commercial applications, and to alter 
 * it and redistribute it freely, subject to the following restrictions:
 *
 * 1. The origin of this software must not be misrepresented; you must not 
 *    claim that you wrote the original software. If you use this software in
 *    a product, an acknowledgment in the product documentation would be 
 *    appreciated but is not required. 
 * 
 * 2. Altered source versions must be plainly marked as such, and must not be 
 *    misrepresented as being the original software. 
 * 
 * 3. This notice may not be removed or altered from any source distribution.
 *   
 *
 * $Date:        16. December 2015
 * $Revision:    V1.01
 *  
 * Project:      Flash Device Description for Freescale MKMxxx Internal Flash
 * --------------------------------------------------------------------------- */

/* History:
 *  Version 1.01
 *    Added MKMP256_2KB
 *  Version 1.00
 *    Initial release
 */ 

#include "..\FlashOS.H"        // FlashOS Structures


#ifdef MKMP64_1KB
struct FlashDevice const FlashDevice  =  {
   FLASH_DRV_VERS,               // Driver Version, do not modify!
   "MKMxx 64KB P-Flash(1KB Sec)",// Device Name 
   ONCHIP,                       // Device Type
   0x00000000,                   // Device Start Address
   0x00010000,                   // Device Size (64kB)
   256,                          // Programming Page Size
   0,                            // Reserved, must be 0
   0xFF,                         // Initial Content of Erased Memory
   1000,                         // Program Page Timeout 1000 mSec
   3000,                         // Erase Sector Timeout 3000 mSec

// Specify Size and Address of Sectors
   0x000400, 0x000000,           // Sector Size  1kB (64 Sectors)
   SECTOR_END
};
#endif

#ifdef MKMP128_1KB
struct FlashDevice const FlashDevice  =  {
   FLASH_DRV_VERS,               // Driver Version, do not modify!
   "MKMxx 128KB P-Flash(1KB Sec)",// Device Name 
   ONCHIP,                       // Device Type
   0x00000000,                   // Device Start Address
   0x00020000,                   // Device Size (128kB)
   256,                          // Programming Page Size
   0,                            // Reserved, must be 0
   0xFF,                         // Initial Content of Erased Memory
   1000,                         // Program Page Timeout 1000 mSec
   3000,                         // Erase Sector Timeout 3000 mSec

// Specify Size and Address of Sectors
   0x000400, 0x000000,           // Sector Size  1kB (128 Sectors)
   SECTOR_END
};
#endif

#ifdef MKMP256_2KB
struct FlashDevice const FlashDevice  =  {
   FLASH_DRV_VERS,               // Driver Version, do not modify!
   "MKMxx 256KB P-Flash(2KB Sec)",// Device Name 
   ONCHIP,                       // Device Type
   0x00000000,                   // Device Start Address
   0x00040000,                   // Device Size (256kB)
   512,                          // Programming Page Size
   0,                            // Reserved, must be 0
   0xFF,                         // Initial Content of Erased Memory
   1000,                         // Program Page Timeout 1000 mSec
   3000,                         // Erase Sector Timeout 3000 mSec

// Specify Size and Address of Sectors
   0x000800, 0x000000,           // Sector Size  1kB (128 Sectors)
   SECTOR_END
};
#endif

#ifdef MKMPIFR                 //Program Flash IFR
struct FlashDevice const FlashDevice  =  {
   FLASH_DRV_VERS,             // Driver Version, do not modify!
   "MKMxx P-Flash IFR",        // Device Name 
   ONCHIP,                     // Device Type
   0x0FFFFFC0,                 // Device Start Address
   0x00000040,                 // Device Size (64 Byte)
   64,                         // Programming Page Size
   0,                          // Reserved, must be 0
   0xFF,                       // Initial Content of Erased Memory
   1000,                       // Program Page Timeout 1000 mSec
   3000,                       // Erase Sector Timeout 3000 mSec
// Specify Size and Address of Sectors
   0x000040, 0x000000,         // Sector Size  64 Byte (1 Sector)
   SECTOR_END
};
#endif

///#ifdef MKDIFR_50MHZ  //Data Flash IFR
///struct FlashDevice const FlashDevice  =  {
///   FLASH_DRV_VERS,             // Driver Version, do not modify!
///   "MKXX 50Mhz Data Flash IFR",// Device Name 
///   ONCHIP,                     // Device Type
///   0x13FFFFFC,                 // Device Start Address
///   0x00000004,                 // Device Size (4 Byte)
///   4,                          // Programming Page Size
///   0,                          // Reserved, must be 0
///   0xFF,                       // Initial Content of Erased Memory
///   1000,                       // Program Page Timeout 1000 mSec
///   3000,                       // Erase Sector Timeout 3000 mSec
///// Specify Size and Address of Sectors
///   0x000004, 0x000000,         // Sector Size  4 Byte (1 Sector)
///   SECTOR_END
///};
///#endif
